@@ -42,15 +42,3 @@ def get_secret(name):
     secret = client.get_secret_value(SecretId=name)
 
     return secret["SecretString"]
-
-
-def get_proxy_token(endpoint: str, port: str, user: str):
-    session = session.Session()
-    client = session.client("rds")
-
-    return client.generate_db_auth_token(
-        DBHostname=endpoint,
-        Port=port,
-        DBUsername=user,
-        Region=AWS_REGION,
-    )
