@@ -1,7 +1,10 @@
-from rispack.database import Database
 from contextlib import contextmanager
-from rispack.logger import logger
 from functools import wraps
+from typing import Union
+from uuid import UUID
+
+from rispack.database import Database
+from rispack.logger import logger
 
 
 def atomic(func):
@@ -48,7 +51,10 @@ class BaseStore:
     def filter_by(self, **kwargs):
         return self.session.query(self.get_mapper()).filter_by(**kwargs)
 
-    def find(self, id: int):
+    def find(self, id: Union[UUID, int, str]):
+        if type(id) is UUID:
+            id = str(id)
+
         return self.filter_by(id=id).first()
 
     def find_by(self, **kwargs):
